%define runuser toruser

Name:		tor
Version:	0.2.4.23
Release:	%mkrel 1
Summary:	Anonymizing overlay network for TCP (The onion router)
URL:		http://www.torproject.org/
Group:		Networking/Other
License:	BSD-like
Requires(post):  systemd >= %{systemd_required_version}
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1
Requires(post):   sysvinit
Requires(preun):  sysvinit
Requires(postun): sysvinit
Requires:	openssl >= 0.9.8
Requires:	tsocks
BuildRequires:	openssl-devel >= 0.9.8
BuildRequires:	libevent-devel
BuildRequires:	zlib-devel
BuildRequires:	autoconf2.5
Source0:	http://www.torproject.org/dist/%{name}-%{version}.tar.gz
Source1:	%{name}.logrotate
Source2:	%{name}.init
Source3: 	%{name}.sysconfig
Source4:	%{name}.service
Source5:	%{name}-tmpfiles.conf

%description
Tor is a connection-based low-latency anonymous communication system.

This package provides the "tor" program, which serves as both a client and
a relay node. Scripts will automatically create a "%{runuser}" user and
group, and set tor up to run as a daemon when the system is rebooted.

Applications connect to the local Tor proxy using the SOCKS
protocol. The local proxy chooses a path through a set of relays, in
which each relay knows its predecessor and successor, but no
others. Traffic flowing down the circuit is unwrapped by a symmetric
key at each relay, which reveals the downstream relay.

Warnings: Tor does no protocol cleaning.  That means there is a danger
that application protocols and associated programs can be induced to
reveal information about the initiator. Tor depends on Privoxy and
similar protocol cleaners to solve this problem. This is alpha code,
and is even more likely than released code to have anonymity-spoiling
bugs. The present network is very small -- this further reduces the
strength of the anonymity provided. Tor is not presently suitable
for high-stakes anonymity.


%prep
%setup -q
 
%build
%configure2_5x
%make

%install
%makeinstall

%define _logdir %{_var}/log

mkdir -p ${RPM_BUILD_ROOT}%{_initrddir}
cat %{SOURCE2} > ${RPM_BUILD_ROOT}%{_initrddir}/%{name}
chmod 0755 ${RPM_BUILD_ROOT}%{_initrddir}/%{name}

install -p -m 644 ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}/torrc.sample ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}/torrc

mkdir -p -m 755 ${RPM_BUILD_ROOT}%{_sysconfdir}/logrotate.d
cat %{SOURCE1} > ${RPM_BUILD_ROOT}%{_sysconfdir}/logrotate.d/%{name}

mkdir -p -m 755 ${RPM_BUILD_ROOT}%{_sysconfdir}/sysconfig/
cat %{SOURCE3} > ${RPM_BUILD_ROOT}%{_sysconfdir}/sysconfig/%{name}

mkdir -p -m 700 ${RPM_BUILD_ROOT}%{_localstatedir}/lib/%{name}
mkdir -p -m 755 ${RPM_BUILD_ROOT}%{_var}/%{name}
mkdir -p -m 755 ${RPM_BUILD_ROOT}%{_logdir}/%{name}

# Bash completion
mkdir -p ${RPM_BUILD_ROOT}%{_sysconfdir}/bash_completion.d
echo 'complete -F _command $filenames torify' > ${RPM_BUILD_ROOT}%{_sysconfdir}/bash_completion.d/%{name}

# Systemd support
install -D -p -m 0644 %{SOURCE4} ${RPM_BUILD_ROOT}%{_unitdir}/%{name}.service
install -D -p -m 0644 %{SOURCE5} %{buildroot}%{_tmpfilesdir}/%{name}.conf

%pre
%_pre_useradd %{runuser} / /bin/false

%post
%_tmpfilescreate %{name}
%_post_service %{name}

%preun
%_preun_service %{name}
rm -f %{_localstatedir}/%{name}/cached-directory
rm -f %{_localstatedir}/%{name}/bw_accounting
rm -f %{_localstatedir}/%{name}/control_auth_cookie
rm -f %{_localstatedir}/%{name}/router.desc
rm -f %{_localstatedir}/%{name}/fingerprint

%postun
%_postun_userdel %{runuser}
%_postun_groupdel %{runuser}

%files
%doc ReleaseNotes INSTALL LICENSE README ChangeLog doc/HACKING
%{_mandir}/man*/*
%{_bindir}/tor
%{_bindir}/torify
%{_bindir}/tor-resolve
%{_bindir}/tor-gencert
%config(noreplace) %attr(0755,%{runuser},%{runuser}) %{_initrddir}/%{name}
%{_unitdir}/%{name}.service
%{_tmpfilesdir}/%{name}.conf
%config(noreplace) %attr(0644,root,root) %{_sysconfdir}/logrotate.d/%{name}
%dir %attr(0755,root,%{runuser}) %{_sysconfdir}/%{name}/
%config(noreplace) %attr(0644,root,%{runuser}) %{_sysconfdir}/%{name}/*
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%attr(0700,%{runuser},%{runuser}) %dir %{_localstatedir}/lib/%{name}
%attr(0750,%{runuser},%{runuser}) %dir %{_var}/%{name}
%attr(0750,%{runuser},%{runuser}) %dir %{_logdir}/%{name}
%{_sysconfdir}/bash_completion.d/%{name}
%{_datadir}/%{name}


%changelog
* Wed Jul 30 2014 luigiwalser <luigiwalser> 0.2.4.23-1.mga3
+ Revision: 658349
- 0.2.4.23 (fixes CVE-2014-5117)
- 0.2.4.22
- remove unnecessary BRs (mga#11922), thanks to roelof for the patch
- 0.2.4.20

  + shlomif <shlomif>
    - New version thanks to Roelof (= my apprentice)

* Sun Mar 24 2013 colin <colin> 0.2.3.25-3.mga3
+ Revision: 405136
- Use tmpfiles macros and add system version to requires (mga#9302)

* Mon Jan 14 2013 umeabot <umeabot> 0.2.3.25-2.mga3
+ Revision: 384656
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 kamil <kamil> 0.2.3.25-1.mga3
+ Revision: 325285
- new version 0.2.3.25
- clean .spec a bit

* Mon Sep 24 2012 kharec <kharec> 0.2.2.39-3.mga3
+ Revision: 297006
- Double bump release to be newer than 2

* Fri Sep 14 2012 kharec <kharec> 0.2.2.39-1.mga3
+ Revision: 293865
- new version 0.2.2.39

* Wed Aug 29 2012 kharec <kharec> 0.2.2.38-1.mga3
+ Revision: 285457
- New upstream release 0.2.2.38

  + colin <colin>
    - Add systemd require for %%post script

* Wed Jul 25 2012 colin <colin> 0.2.2.37-2.mga3
+ Revision: 274221
- Fix tor systemd unit (mga#6843)
- Use tmpfiles for pid dir

* Thu Jun 14 2012 fwang <fwang> 0.2.2.37-1.mga3
+ Revision: 260410
- new version 0.2.2.37

* Fri Jun 08 2012 fwang <fwang> 0.2.2.36-1.mga3
+ Revision: 257305
- new version 0.2.2.36

* Sat Apr 28 2012 tmb <tmb> 0.2.2.35-5.mga2
+ Revision: 233880
- Require rpm-helper >= 0.24.8-1 for systemd support

* Sat Apr 21 2012 colin <colin> 0.2.2.35-4.mga2
+ Revision: 232395
- Tidy up systemd unit.

* Mon Jan 23 2012 dmorgan <dmorgan> 0.2.2.35-3.mga2
+ Revision: 200138
- Own %%{_var}/%%{name}

* Sun Jan 15 2012 dmorgan <dmorgan> 0.2.2.35-2.mga2
+ Revision: 196574
- Add systemd support ( from fedora)

* Sat Dec 17 2011 kharec <kharec> 0.2.2.35-1.mga2
+ Revision: 183206
- new version 0.2.2.35

* Fri Sep 23 2011 boklm <boklm> 0.2.2.33-1.mga2
+ Revision: 147145
- update to version 0.2.2.33

  + fwang <fwang>
    - new version 0.2.2.32

* Thu Mar 17 2011 boklm <boklm> 0.2.1.30-1.mga1
+ Revision: 73394
- imported package tor

